@@ -1,5 +1,6 @@
 import brokerlink
 import unittest
+import socket
 
 
 class BrokerlinkTests(unittest.TestCase):
@@ -8,24 +9,28 @@ class BrokerlinkTests(unittest.TestCase):
         rhbz#1075126
         """
         b = brokerlink.BrokerLink()
+        b._socket = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
         b._communicate = lambda req: "success"
         ret = b._checked_communicate("dummy request")
         self.assertEqual("", ret)
 
     def test_checked_communicate_fail_no_data(self):
         b = brokerlink.BrokerLink()
+        b._socket = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
         b._communicate = lambda req: "failure"
         self.assertRaises(brokerlink.RequestError,
                           b._checked_communicate, "dummy request")
 
     def test_checked_communicate_fail_data(self):
         b = brokerlink.BrokerLink()
+        b._socket = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
         b._communicate = lambda req: "failure data"
         self.assertRaises(brokerlink.RequestError,
                           b._checked_communicate, "dummy request")
 
     def test_checked_communicate_data(self):
         b = brokerlink.BrokerLink()
+        b._socket = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
         b._communicate = lambda req: "success data"
         ret = b._checked_communicate("dummy request")
         self.assertEqual("data", ret)
